@@ -447,7 +447,7 @@ class SQLiteHandler(object):
         # print(table.name)
         records = self.table_read_records(table.name)
         
-        # print(records)
+        print(records)
 
         records_found = []
         for record in records:
@@ -457,7 +457,7 @@ class SQLiteHandler(object):
                         records_found += [record]
                         break
 
-        return records
+        return records_found
 
     def record_create(self, tablename, values=[], recordarray=[]):
         """
